@@ -26,7 +26,7 @@ use overload '='  => sub { $_[0]->clone() },
              '""' => sub { $_[0]->get_description() }, # FIXME: perhaps unwise?
              'fallback' => 1;
 
-sub clone() {
+sub clone {
   my $self = shift;
   my $class = ref( $self );
   my $copy = new2( $self );
@@ -34,7 +34,7 @@ sub clone() {
   return $copy;
 }
 
-sub new() {
+sub new {
   my $class = shift;
   my $query;
   my $invalid_args;
@@ -81,6 +81,23 @@ sub new() {
   return $query;
 }
 
+sub new_term {
+  my $class = shift;
+  my $query;
+
+  if (@_ < 1 or @_ > 3) {
+    Carp::carp( "new_term takes 1, 2 or 3 arguments only" );
+  }
+  my ($term, $wqf, $pos) = @_;
+  $wqf = 1 unless defined $wqf;
+  $pos = 0 unless defined $pos;
+
+  $query = new1weight($term, $wqf, $pos);
+
+  bless $query, $class;
+  return $query;
+}
+
 sub _all_equal {
   my $first = shift;
   while(@_) {
@@ -89,4 +106,16 @@ sub _all_equal {
   return 1;
 }
 
+sub get_terms {
+    my $self = shift;
+    my @terms;
+    my $q=$self->get_terms_begin;
+    while ($q ne $self->get_terms_end) {
+        push @terms,$q->get_termname;
+        $q++;
+    }
+    return @terms;
+}
+
+
 1;
